@@ -4,7 +4,7 @@ from __future__ import annotations
 from collections import defaultdict, OrderedDict
 from itertools import chain
 from pathlib import Path
-from typing import Any, Iterable, Optional, Union
+from typing import Any, DefaultDict, Dict, Iterable, List, Optional, Set, Tuple, Union
 import warnings
 
 try:
@@ -110,17 +110,17 @@ class SpaczzRuler:
             TypeError: If spaczz_{name}_defaults passed are not dictionaries.
         """
         self.nlp = nlp
-        self.fuzzy_patterns: defaultdict[str, defaultdict[str, Any]] = nest_defaultdict(
+        self.fuzzy_patterns: DefaultDict[str, DefaultDict[str, Any]] = nest_defaultdict(
             list, 2
         )
-        self.regex_patterns: defaultdict[str, defaultdict[str, Any]] = nest_defaultdict(
+        self.regex_patterns: DefaultDict[str, DefaultDict[str, Any]] = nest_defaultdict(
             list, 2
         )
-        self.token_patterns: defaultdict[str, list[list[dict[str, Any]]]] = defaultdict(
+        self.token_patterns: DefaultDict[str, List[List[Dict[str, Any]]]] = defaultdict(
             list
         )
         self.ent_id_sep = cfg.get("spaczz_ent_id_sep", DEFAULT_ENT_ID_SEP)
-        self._ent_ids: defaultdict[Any, Any] = defaultdict(dict)
+        self._ent_ids: DefaultDict[Any, Any] = defaultdict(dict)
         self.overwrite = cfg.get("spaczz_overwrite_ents", False)
         default_names = (
             ("spaczz_fuzzy_defaults", "fuzzy_defaults"),
@@ -140,7 +140,8 @@ class SpaczzRuler:
                         )
                     )
         self.fuzzy_matcher = FuzzyMatcher(
-            nlp.vocab, **self.defaults.get("fuzzy_defaults", {}),
+            nlp.vocab,
+            **self.defaults.get("fuzzy_defaults", {}),
         )
         self.regex_matcher = RegexMatcher(
             nlp.vocab,
@@ -183,7 +184,7 @@ class SpaczzRuler:
         return n_fuzzy_patterns + n_regex_patterns + n_token_patterns
 
     @property
-    def ent_ids(self: SpaczzRuler) -> tuple[Optional[str], ...]:
+    def ent_ids(self: SpaczzRuler) -> Tuple[Optional[str], ...]:
         """All entity ids present in the match patterns id properties.
 
         Returns:
@@ -202,7 +203,7 @@ class SpaczzRuler:
         return all_ent_ids_tuple
 
     @property
-    def labels(self: SpaczzRuler) -> tuple[str, ...]:
+    def labels(self: SpaczzRuler) -> Tuple[str, ...]:
         """All labels present in the ruler.
 
         Returns:
@@ -221,7 +222,7 @@ class SpaczzRuler:
         return tuple(all_labels)
 
     @property
-    def patterns(self: SpaczzRuler) -> list[dict[str, Any]]:
+    def patterns(self: SpaczzRuler) -> List[Dict[str, Any]]:
         """Get all patterns and kwargs that were added to the ruler.
 
         Returns:
@@ -259,7 +260,10 @@ class SpaczzRuler:
                 all_patterns.append(p)
         return all_patterns
 
-    def add_patterns(self: SpaczzRuler, patterns: Iterable[dict[str, Any]],) -> None:
+    def add_patterns(
+        self: SpaczzRuler,
+        patterns: Iterable[Dict[str, Any]],
+    ) -> None:
         """Add patterns to the ruler.
 
         A pattern must be a spaczz pattern:
@@ -380,12 +384,13 @@ class SpaczzRuler:
 
     def match(
         self: SpaczzRuler, doc: Doc
-    ) -> tuple[
-        list[tuple[str, int, int]], defaultdict[str, dict[tuple[str, int, int], Any]],
+    ) -> Tuple[
+        List[Tuple[str, int, int]],
+        DefaultDict[str, Dict[Tuple[str, int, int], Any]],
     ]:
         """Used in call to find matches in a doc."""
         fuzzy_matches = []
-        lookup: defaultdict[str, dict[tuple[str, int, int], Any]] = defaultdict(dict)
+        lookup: DefaultDict[str, Dict[Tuple[str, int, int], Any]] = defaultdict(dict)
         for fuzzy_match in self.fuzzy_matcher(doc):
             current_ratio = fuzzy_match[3]
             best_ratio = lookup["ratios"].get(fuzzy_match[:3], 0)
@@ -410,15 +415,15 @@ class SpaczzRuler:
     def set_annotations(
         self: SpaczzRuler,
         doc: Doc,
-        matches: list[tuple[str, int, int]],
-        lookup: defaultdict[
-            str, dict[tuple[str, int, int], Union[int, tuple[int, int, int]]]
+        matches: List[Tuple[str, int, int]],
+        lookup: DefaultDict[
+            str, Dict[Tuple[str, int, int], Union[int, Tuple[int, int, int]]]
         ],
     ) -> None:
         """Modify the document in place."""
         entities = list(doc.ents)
         new_entities = []
-        seen_tokens: set[int] = set()
+        seen_tokens: Set[int] = set()
         for match_id, start, end in matches:
             if any(t.ent_type for t in doc[start:end]) and not self.overwrite:
                 continue
@@ -568,9 +573,9 @@ class SpaczzRuler:
 
     def _add_patterns(
         self: SpaczzRuler,
-        fuzzy_patterns: list[dict[str, Any]],
-        regex_patterns: list[dict[str, Any]],
-        token_patterns: list[dict[str, Any]],
+        fuzzy_patterns: List[Dict[str, Any]],
+        regex_patterns: List[Dict[str, Any]],
+        token_patterns: List[Dict[str, Any]],
     ) -> None:
         """Helper function for add_patterns."""
         for entry in fuzzy_patterns + regex_patterns + token_patterns:
@@ -619,7 +624,7 @@ class SpaczzRuler:
             label = f"{label}{self.ent_id_sep}{ent_id}"
         return label
 
-    def _split_label(self: SpaczzRuler, label: str) -> tuple[str, Union[str, None]]:
+    def _split_label(self: SpaczzRuler, label: str) -> Tuple[str, Union[str, None]]:
         """Split Entity label into ent_label and ent_id if it contains self.ent_id_sep.
 
         Args:
@@ -637,10 +642,10 @@ class SpaczzRuler:
 
     @staticmethod
     def _filter_overlapping_matches(
-        matches: list[tuple[str, int, int]],
-        lookup: defaultdict[str, dict[tuple[str, int, int], Any]],
-    ) -> tuple[
-        list[tuple[str, int, int]], defaultdict[str, dict[tuple[str, int, int], Any]]
+        matches: List[Tuple[str, int, int]],
+        lookup: DefaultDict[str, Dict[Tuple[str, int, int], Any]],
+    ) -> Tuple[
+        List[Tuple[str, int, int]], DefaultDict[str, Dict[Tuple[str, int, int], Any]]
     ]:
         """Prevents multiple match spans from overlapping.
 
@@ -661,7 +666,7 @@ class SpaczzRuler:
         Returns:
             The filtered list of match span tuples and the lookup dict.
         """
-        filtered_matches: list[tuple[str, int, int]] = []
+        filtered_matches: List[Tuple[str, int, int]] = []
         for match in matches:
             if not set(range(match[1], match[2])).intersection(
                 chain(*[set(range(n[1], n[2])) for n in filtered_matches])
@@ -678,7 +683,7 @@ class SpaczzRuler:
     def _update_custom_attrs(
         span: Span,
         match_id: str,
-        lookup: defaultdict[str, dict[tuple[str, int, int], Any]],
+        lookup: DefaultDict[str, Dict[Tuple[str, int, int], Any]],
     ) -> Span:
         """Update custom attributes for matches."""
         ratio = lookup["ratios"].get((match_id, span.start, span.end))
