@@ -13,7 +13,9 @@ _commonregex = {
         \s+(?<!\:)(?<!\:\d)[0-3]?\d(?:st|nd|rd|th)?)(?:\,)?\s*(?:\d{4})?
         |[0-3]?\d[-\./][0-3]?\d[-\./]\d{2,4}""",
     ),
-    "times": regex.compile(r"(?i)\d{1,2}:\d{2} ?(?:[ap]\.?m\.?)?|\d[ap]\.?m\.?",),
+    "times": regex.compile(
+        r"(?i)\d{1,2}:\d{2} ?(?:[ap]\.?m\.?)?|\d[ap]\.?m\.?",
+    ),
     "phones": regex.compile(
         r"""(?ix)((?:(?<![\d-])(?:\+?\d{1,3}[-.\s*]?)?(?:\(?\d{3}\)?[-.\s*]?)?\d
         {3}[-.\s*]?\d{4}(?![\d-]))|(?:(?<![\d-])(?:(?:\(\+?\d{2}\))|(?:\+?\d
